#
# SOAPCCproxy.py - proxy a IM Model out to a SOAP Server
#
# stardrop-support@optibrium.com
# Optibrium Ltd (C) 2009
#

# example python plugin-model
#
# defines a continuous model which will proxy out to a 
# SOAP service using SOAPpy (listening on "localhost:4711"
# or values defined in soapconfig.py)
# 
# you must install PyXML and fpconst as well as SOAPpy.
# (for Python 2.5 you may need to comment out some 
# "from __future__ import nested_scopes" SOAPpy lines).


import SOAPpy

servername = "localhost"
serverport = 4712
try:
  import soapconfig
  servername = soapconfig.servername
  serverport = soapconfig.serverport
except:
  print "using server address defaults"
  pass

from implugin import IMPlugin

from modeldescriptions import ContModelDescription

class SOAPCCProxy(IMPlugin):
  def __init__(self):
    model = ContModelDescription('SOAP_C_COUNT', 
                                  0.0,
                                  10000.0,
                                  header='SOAP Carbon Count',
                                  glowingCapable = True,
                                  interactive = True,
                                  shortName = 'SOAP CC',
                                  longName = 'SOAP CC',
                                  description = 'Call a SOAP service to count the carbons in the molecule')
    IMPlugin.__init__(self, model)
                                            
  def predict(self, smiles, extra):
    url = "http://" + servername + ":" + str(serverport)
    server = SOAPpy.SOAPProxy(url) 
    gmReq = type(extra) == type(True)

    r = server.predict(smiles, extra, gmReq)

    if r == "None" or r == None or r == []: 
      return []
    if gmReq and len(r) == 3 and r[2] != "":
      return [[r[0], r[1]], r[2]]
    else:
      return [r[0], r[1]] # convert to vanilla tuple

class Plugin(SOAPCCProxy): # the hook
   pass
